redvox.api900.constants API documentation
Description: This modules contains constants used throughout the SDK.

# Module `redvox.api900.constants`

This modules contains constants used throughout the SDK.

Expand source code

    """
    This modules contains constants used throughout the SDK.
    """

    import enum

    class PayloadType(enum.Enum):
        """
        This class provides type safe constants for API 900 payload types.
        """
        BYTE_PAYLOAD: str = "byte_payload"
        UINT32_PAYLOAD: str = "uint32_payload"
        UINT64_PAYLOAD: str = "uint64_payload"
        INT32_PAYLOAD: str = "int32_payload"
        INT64_PAYLOAD: str = "int64_payload"
        FLOAT32_PAYLOAD: str = "float32_payload"
        FLOAT64_PAYLOAD: str = "float64_payload"

## Classes

`class PayloadType (value, names=None, *, module=None, qualname=None, type=None, start=1)`

  This class provides type safe constants for API 900 payload types.

  Expand source code

      class PayloadType(enum.Enum):
          """
          This class provides type safe constants for API 900 payload types.
          """
          BYTE_PAYLOAD: str = "byte_payload"
          UINT32_PAYLOAD: str = "uint32_payload"
          UINT64_PAYLOAD: str = "uint64_payload"
          INT32_PAYLOAD: str = "int32_payload"
          INT64_PAYLOAD: str = "int64_payload"
          FLOAT32_PAYLOAD: str = "float32_payload"
          FLOAT64_PAYLOAD: str = "float64_payload"

  ### Ancestors

  - enum.Enum

  ### Class variables

  `var BYTE_PAYLOAD : str`
  `var FLOAT32_PAYLOAD : str`
  `var FLOAT64_PAYLOAD : str`
  `var INT32_PAYLOAD : str`
  `var INT64_PAYLOAD : str`
  `var UINT32_PAYLOAD : str`
  `var UINT64_PAYLOAD : str`